@@ -5,7 +5,7 @@
 
 package XML::Compile::Translate::Template;
 use vars '$VERSION';
-$VERSION = '1.36';
+$VERSION = '1.37';
 
 use base 'XML::Compile::Translate';
 
@@ -204,7 +204,7 @@ sub makeElement
 sub makeElementDefault
 {   my ($self, $path, $ns, $childname, $do, $default) = @_;
     sub { my $h = $do->(@_);
-          $h->{occur}   = "defaults to $default";
+          $h->{occur}   = "defaults to '$default'";
           $h->{example} = $default;
           $h;
         };
@@ -213,7 +213,7 @@ sub makeElementDefault
 sub makeElementFixed
 {   my ($self, $path, $ns, $childname, $do, $fixed) = @_;
     sub { my $h = $do->(@_);
-          $h->{occur}   = "fixed to $fixed";
+          $h->{occur}   = "fixed to '$fixed'";
           $h->{example} = $fixed;
           $h;
         };
